/* 
Surrey Police Spending code by Bob Foreman(robert.foreman@lexisnexis.com)
Licensed under Open Governemnt License: http://www.nationalarchives.gov.uk/doc/open-government-licence/
Data Source from HM Government: http://data.gov.uk which linked to:
   http://www.spotlightonspend.org.uk/Downloads
   Go to the Monthly Data link near the bottom of the page, open 
   Police, Fire, and Emergency Services
   Surrey Police
   2009 - April through September
   2010 - January through March
   
The above zip files comprise the spending from April 2009 through March 2010 
of the Surrey Police department in the United Kingdom 
After downloads, I opened a text editor and merged all monthly CSV files
into a single CSV file for simple spraying:
SurreyPoliceLineLevelData20092010.zip (this file is attached to this submission
for your convenience. 
   
    1. Extract the zip file and copy the SurreyPoliceLineLevelData20092010.csv to your landing (drop) zone
    2. Open your ECL Watch tool and select the Spray CSV option
    3. Accept the CSV defaults, and enter 'ECLDATA::IN::SurreyPolice' as the Destination Label
    4. Press Submit to spray
*/


//ECL Code:
//At the top of the CSV file downloaded I found:
//Entity,Date,Expense Area,Supplier,Transaction Number,Amount
//Translating to an ECL RECORD Definition:

Layout_SpendRec := RECORD
 STRING30  Entity;     //Always Surrey Police, but expanded for future integration
 STRING10  Date;       // dd/mm/yyyy format
 STRING50  ExpenseArea;
 STRING50  Supplier;
 UNSIGNED3 TransNum;   //5-digit code
 DECIMAL7_2 Amount;
END;

File_SurreySpend := DATASET('~ECLDATA::IN::SurreyPolice',Layout_SpendRec,CSV);

 //First, let's look at the raw output that we sprayed to our cluster:
 OUTPUT(File_SurreySpend,NAMED('Original_Dataset'));

//Next, let's get a distinct count of our suppliers
 SpendVerticalSlice := RECORD
  my_supplier := File_SurreySpend.Supplier;
 END; 
   
 SLICE := TABLE(File_SurreySpend,SpendVerticalSlice);
 OUTPUT(SORT(SLICE,my_supplier),NAMED('Sorted_TABLE_Output'));
 
 OUTPUT(COUNT(DEDUP(SLICE)),NAMED('Unique_Supplier')); //will show 5702 distinct suppliers


//Now let's see who is the biggest supplier during this time frame
SpendAgg := RECORD
 my_supplier := File_SurreySpend.Supplier;
 frequency   := COUNT(GROUP);
END; 
      
Agg := TABLE(File_SurreySpend,SpendAgg, supplier);
SortAgg := SORT(Agg,-Frequency);
   
OUTPUT(SortAgg,NAMED('Most_Active_Supplier'));


//Finally, where has all of the money gone in this time frame?
NewSpendAgg := RECORD
 my_supplier       := File_SurreySpend.Supplier;
 frequency         := COUNT(GROUP);
 sum_cost          := SUM(GROUP,File_SurreySpend.Amount);
 avg_cost_rounded  := ROUND(AVE(GROUP,File_SurreySpend.Amount));
 Biggest_amt_spent := MAX(GROUP,File_SurreySpend.Amount);
 END; 
      
 BigSpendAgg := TABLE(File_SurreySpend,NewSpendAgg, supplier);
 SortBigSpendAgg := SORT(BigSpendAgg,-sum_cost);
   
 OUTPUT(SortBigSpendAgg,NAMED('Sum_Cost_List'));

//End of ECL Code

   
   


